==> grasspy-xlwings-0.2.276.tar.gz: grasspy-xlwings-0.2.276/src/格子/常量.py <==
_图表类型字典 = {
    '三维面积图' : '3d_area',
    '三维堆积面积图' : '3d_area_stacked',
    '三维百分比堆积面积图' : '3d_area_stacked_100',
    '三维簇状条形图' : '3d_bar_clustered',
    '三维堆积条形图' : '3d_bar_stacked',
    '三维百分比堆积条形图' : '3d_bar_stacked_100',
    '三维柱形图' : '3d_column',
    '三维簇状柱形图' : '3d_column_clustered',
    '三维堆积柱形图' : '3d_column_stacked',
    '三维百分比堆积柱形图' : '3d_column_stacked_100',
    '三维折线图' : '3d_line',
    '三维饼图' : '3d_pie',
    '分离型三维饼图' : '3d_pie_exploded',
    '面积图' : 'area',
    '堆积面积图' : 'area_stacked',
    '百分比堆积面积图' : 'area_stacked_100',
    '簇状条形图' : 'bar_clustered',
    '复合条饼图' : 'bar_of_pie',
    '堆积条形图' : 'bar_stacked',
    '百分比堆积条形图' : 'bar_stacked_100',
    '气泡图' : 'bubble',
    '三维气泡图' : 'bubble_3d_effect',
    '簇状柱形图' : 'column_clustered',
    '堆积柱形图' : 'column_stacked',
    '百分比堆积柱形图' : 'column_stacked_100',
    # '复合图' : 'combination',
    '簇状水平圆锥图' : 'cone_bar_clustered',
    '堆积水平圆锥图' : 'cone_bar_stacked',
    '百分比堆积水平圆锥图' : 'cone_bar_stacked_100',
    '三维圆锥图' : 'cone_col',
    '簇状圆锥图' : 'cone_col_clustered',
    '堆积圆锥图' : 'cone_col_stacked',
    '百分比堆积圆锥图' : 'cone_col_stacked_100',
    '簇状水平圆柱图' : 'cylinder_bar_clustered',
    '堆积水平圆柱图' : 'cylinder_bar_stacked',
    '百分比堆积水平圆柱图' : 'cylinder_bar_stacked_100',
    '三维圆柱图' : 'cylinder_col',
    '簇状圆柱图' : 'cylinder_col_clustered',
    '堆积圆柱图' : 'cylinder_col_stacked',
    '百分比堆积圆柱图' : 'cylinder_col_stacked_100',
    '圆环图' : 'doughnut',
    '分离型圆环图' : 'doughnut_exploded',
    '折线图' : 'line',
    '带数据标记的折线图' : 'line_markers',
    '带数据标记的堆积折线图' : 'line_markers_stacked',
    '带数据标记的百分比堆积折线图' : 'line_markers_stacked_100',
    '堆积折线图' : 'line_stacked',
    '百分比堆积折线图' : 'line_stacked_100',
    '饼图' : 'pie',
    '分离型饼图' : 'pie_exploded',
    '复合饼图' : 'pie_of_pie',
    '簇状水平棱锥图' : 'pyramid_bar_clustered',
    '堆积水平棱锥图' : 'pyramid_bar_stacked',
    '百分比堆积水平棱锥图' : 'pyramid_bar_stacked_100',
    '三维棱锥图' : 'pyramid_col',
    '簇状棱锥图' : 'pyramid_col_clustered',
    '堆积棱锥图' : 'pyramid_col_stacked',
    '百分比堆积棱锥图' : 'pyramid_col_stacked_100',
    '雷达图' : 'radar',
    '填充雷达图' : 'radar_filled',
    '带数据标记的雷达图' : 'radar_markers',
    # '盘高-盘低-收盘图' : 'stock_hlc',
    # '开盘-盘高-盘低-收盘图' : 'stock_ohlc',
    # '成交量-盘高-盘低-收盘图' : 'stock_vhlc',
    # '成交量-开盘-盘高-盘低-收盘图' : 'stock_vohlc',
    # '曲面图' : 'surface',
    # '三维曲面图' : 'surface_top_view',
    # '曲面图(俯视框架图)' : 'surface_top_view_wireframe',
    # '三维曲面图(框架图)' : 'surface_wireframe',
    '散点图' : 'xy_scatter',
    '带直线和数据标记的散点图' : 'xy_scatter_lines',
    '带直线的散点图' : 'xy_scatter_lines_no_markers',
    '带平滑线的散点图' : 'xy_scatter_smooth',
    '带平滑线和数据标记的散点图' : 'xy_scatter_smooth_no_markers'
}

_图表类型字典英中 = 字典型([值, 键] 取 键, 值 于 _图表类型字典.项々())

==> grasspy-xlwings-0.3.276.tar.gz: grasspy-xlwings-0.3.276/src/格子/常量.py <==
_图表类型字典 = {
    '三维面积图' : '3d_area',
    '三维堆积面积图' : '3d_area_stacked',
    '三维百分比堆积面积图' : '3d_area_stacked_100',
    '三维簇状条形图' : '3d_bar_clustered',
    '三维堆积条形图' : '3d_bar_stacked',
    '三维百分比堆积条形图' : '3d_bar_stacked_100',
    '三维柱形图' : '3d_column',
    '三维簇状柱形图' : '3d_column_clustered',
    '三维堆积柱形图' : '3d_column_stacked',
    '三维百分比堆积柱形图' : '3d_column_stacked_100',
    '三维折线图' : '3d_line',
    '三维饼图' : '3d_pie',
    '分离型三维饼图' : '3d_pie_exploded',
    '面积图' : 'area',
    '堆积面积图' : 'area_stacked',
    '百分比堆积面积图' : 'area_stacked_100',
    '簇状条形图' : 'bar_clustered',
    '复合条饼图' : 'bar_of_pie',
    '堆积条形图' : 'bar_stacked',
    '百分比堆积条形图' : 'bar_stacked_100',
    '气泡图' : 'bubble',
    '三维气泡图' : 'bubble_3d_effect',
    '簇状柱形图' : 'column_clustered',
    '堆积柱形图' : 'column_stacked',
    '百分比堆积柱形图' : 'column_stacked_100',
    '复合图' : 'combination',
    '簇状水平圆锥图' : 'cone_bar_clustered',
    '堆积水平圆锥图' : 'cone_bar_stacked',
    '百分比堆积水平圆锥图' : 'cone_bar_stacked_100',
    '三维圆锥图' : 'cone_col',
    '簇状圆锥图' : 'cone_col_clustered',
    '堆积圆锥图' : 'cone_col_stacked',
    '百分比堆积圆锥图' : 'cone_col_stacked_100',
    '簇状水平圆柱图' : 'cylinder_bar_clustered',
    '堆积水平圆柱图' : 'cylinder_bar_stacked',
    '百分比堆积水平圆柱图' : 'cylinder_bar_stacked_100',
    '三维圆柱图' : 'cylinder_col',
    '簇状圆柱图' : 'cylinder_col_clustered',
    '堆积圆柱图' : 'cylinder_col_stacked',
    '百分比堆积圆柱图' : 'cylinder_col_stacked_100',
    '圆环图' : 'doughnut',
    '分离型圆环图' : 'doughnut_exploded',
    '折线图' : 'line',
    '带数据标记的折线图' : 'line_markers',
    '带数据标记的堆积折线图' : 'line_markers_stacked',
    '带数据标记的百分比堆积折线图' : 'line_markers_stacked_100',
    '堆积折线图' : 'line_stacked',
    '百分比堆积折线图' : 'line_stacked_100',
    '饼图' : 'pie',
    '分离型饼图' : 'pie_exploded',
    '复合饼图' : 'pie_of_pie',
    '簇状水平棱锥图' : 'pyramid_bar_clustered',
    '堆积水平棱锥图' : 'pyramid_bar_stacked',
    '百分比堆积水平棱锥图' : 'pyramid_bar_stacked_100',
    '三维棱锥图' : 'pyramid_col',
    '簇状棱锥图' : 'pyramid_col_clustered',
    '堆积棱锥图' : 'pyramid_col_stacked',
    '百分比堆积棱锥图' : 'pyramid_col_stacked_100',
    '雷达图' : 'radar',
    '填充雷达图' : 'radar_filled',
    '带数据标记的雷达图' : 'radar_markers',
    '盘高-盘低-收盘图' : 'stock_hlc',
    '开盘-盘高-盘低-收盘图' : 'stock_ohlc',
    '成交量-盘高-盘低-收盘图' : 'stock_vhlc',
    '成交量-开盘-盘高-盘低-收盘图' : 'stock_vohlc',
    '曲面图' : 'surface',
    '三维曲面图' : 'surface_top_view',
    '曲面图(俯视框架图)' : 'surface_top_view_wireframe',
    '三维曲面图(框架图)' : 'surface_wireframe',
    '散点图' : 'xy_scatter',
    '带直线和数据标记的散点图' : 'xy_scatter_lines',
    '带直线的散点图' : 'xy_scatter_lines_no_markers',
    '带平滑线的散点图' : 'xy_scatter_smooth',
    '带平滑线和数据标记的散点图' : 'xy_scatter_smooth_no_markers'
}

_图表类型字典英中 = 字典型([值, 键] 取 键, 值 于 _图表类型字典.项々())
